==> xoops-2.4.5-rc3.zip: xoops-2.4.5-rc3/htdocs/class/xoopsformloader.php <==
<?php
/*
 You may not change or alter any portion of this comment or credits
 of supporting developers from this source code or any supporting source code
 which is considered copyrighted (c) material of the original comment or credit authors.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

/**
 *  Xoops Form Class Elements
 *
 * @copyright       The XOOPS Project http://sourceforge.net/projects/xoops/
 * @license         http://www.fsf.org/copyleft/gpl.html GNU public license
 * @package         kernel
 * @since           2.0.0
 * @author          Kazumi Ono <onokazu@xoops.org>
 * @version         $Id: xoopsformloader.php 4857 2010-06-16 02:36:42Z phppp $
 */

xoops_load('XoopsForm');
xoops_load('XoopsThemeForm');
xoops_load('XoopsSimpleForm');
xoops_load('XoopsFormElement');
xoops_load('XoopsFormElementTray');
xoops_load('XoopsFormLabel');
xoops_load('XoopsFormCheckBox');
xoops_load('XoopsFormPassword');
xoops_load('XoopsFormButton');
xoops_load('XoopsFormButtonTray'); // To be cleaned
xoops_load('XoopsFormHidden');
xoops_load('XoopsFormFile');
xoops_load('XoopsFormRadio');
xoops_load('XoopsFormRadioYN');
xoops_load('XoopsFormSelect');
xoops_load('XoopsFormSelectGroup');
xoops_load('XoopsFormSelectCheckGroup'); // To be cleaned
xoops_load('XoopsFormSelectUser');
xoops_load('XoopsFormSelectTheme');
xoops_load('XoopsFormSelectMatchOption');
xoops_load('XoopsFormSelectCountry');
xoops_load('XoopsFormSelectTimeZone');
xoops_load('XoopsFormSelectLang');
xoops_load('XoopsFormSelectEditor');
xoops_load('XoopsFormText');
xoops_load('XoopsFormTextArea');
xoops_load('XoopsFormTextDateSelect');
xoops_load('XoopsFormDhtmlTextArea');
xoops_load('XoopsFormDateTime');
xoops_load('XoopsFormHiddenToken');
xoops_load('XoopsFormColorPicker');
xoops_load('XoopsFormCaptcha');
xoops_load('XoopsFormEditor');

?>

==> xoops-2.5.0.zip: xoops-2.5.0/htdocs/class/xoopsformloader.php <==
<?php
/**
 * XOOPS form class loader
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting source code
 * which is considered copyrighted (c) material of the original comment or credit authors.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * @copyright       The XOOPS Project http://sourceforge.net/projects/xoops/
 * @license         GNU GPL 2 (http://www.gnu.org/licenses/old-licenses/gpl-2.0.html)
 * @package         kernel
 * @since           2.0.0
 * @version         $Id: xoopsformloader.php 4941 2010-07-22 17:13:36Z beckmi $
 */


xoops_load('XoopsForm');
xoops_load('XoopsThemeForm');
xoops_load('XoopsSimpleForm');
xoops_load('XoopsFormElement');
xoops_load('XoopsFormElementTray');
xoops_load('XoopsFormLabel');
xoops_load('XoopsFormCheckBox');
xoops_load('XoopsFormPassword');
xoops_load('XoopsFormButton');
xoops_load('XoopsFormButtonTray'); // To be cleaned
xoops_load('XoopsFormHidden');
xoops_load('XoopsFormFile');
xoops_load('XoopsFormRadio');
xoops_load('XoopsFormRadioYN');
xoops_load('XoopsFormSelect');
xoops_load('XoopsFormSelectGroup');
xoops_load('XoopsFormSelectCheckGroup'); // To be cleaned
xoops_load('XoopsFormSelectUser');
xoops_load('XoopsFormSelectTheme');
xoops_load('XoopsFormSelectMatchOption');
xoops_load('XoopsFormSelectCountry');
xoops_load('XoopsFormSelectTimeZone');
xoops_load('XoopsFormSelectLang');
xoops_load('XoopsFormSelectEditor');
xoops_load('XoopsFormText');
xoops_load('XoopsFormTextArea');
xoops_load('XoopsFormTextDateSelect');
xoops_load('XoopsFormDhtmlTextArea');
xoops_load('XoopsFormDateTime');
xoops_load('XoopsFormHiddenToken');
xoops_load('XoopsFormColorPicker');
xoops_load('XoopsFormCaptcha');
xoops_load('XoopsFormEditor');

?>
